import { Page } from "@/pages/base";
import { Management } from "@/management/main";
import { Box, Container, Typography } from "@material-ui/core";
import React, { useCallback } from "react";
import { useTranslation } from "react-i18next";
import { useAsync } from "@/hooks";
import api from "@/management/api";
import { Async } from "@/components/async";
import MaterialTable, { Action, Column } from "material-table";
import { default as StaticPage } from "@/data/page";
import { Edition } from "@/data/edition";
import { Delete, Pencil } from "mdi-material-ui";

export const StaticPageManagement = () => {
    const { t } = useTranslation("management");
    const pages = useAsync(useCallback(api.page.all, []));

    const columns: Column<StaticPage>[] = [
        {
            render: page => page.title.pl,
            title: t("page.field.title"),
        },
        {
            field: "slug",
            title: t("page.field.slug"),
        },
    ];

    const actions: Action<StaticPage>[] = [
        {
            icon: () => <Pencil />,
            onClick: () => {},
        },
        {
            icon: () => <Delete />,
            onClick: () => {},
        },
    ]

    const PagePreview = ({ page }: { page: StaticPage }) =>
        <>
            <Box p={2}>
                <Typography variant="subtitle2">Polski</Typography>
                <Typography variant="h2">{ page.title.pl }</Typography>
                <div dangerouslySetInnerHTML={{ __html: page.content.pl }} />
            </Box>
            <Box p={2}>
                <Typography variant="subtitle2">English</Typography>
                <Typography variant="h2">{ page.title.en }</Typography>
                <div dangerouslySetInnerHTML={{ __html: page.content.en }} />
            </Box>
        </>

    return <Page>
        <Page.Header maxWidth="lg">
            <Management.Breadcrumbs>
                <Typography color="textPrimary">{ t("page.index.title") }</Typography>
            </Management.Breadcrumbs>
            <Page.Title>{ t("page.index.title") }</Page.Title>
        </Page.Header>
        <Container maxWidth="lg">
            <Async async={ pages }>{
                pages => <MaterialTable
                    title={ t("page.index.title") }
                    columns={ columns }
                    actions={ actions }
                    data={ pages }
                    detailPanel={ page => <PagePreview page={ page } /> }
                    options={{ actionsColumnIndex: -1 }}
                />
            }</Async>
        </Container>
    </Page>
}

export default StaticPageManagement;
